#! /usr/bin/python3
"""
* SPDX-License-Identifier: GPL-3.0-or-later
*
* Author: Tommy McGee (tommy.mcgee@opensource.wdc.com)
*
* Copyright (c) 2022 Western Digital Corporation or its affiliates.
*
* This script is used to determine if Zone Block Device is supported
"""
import zbd_checker.utils.kernel_config_info
import zbd_checker.utils.os_details
import zbd_checker.utils.pkg_details

def zbd_check():
    """
    This main application will call other functions from other
    modules to display information about the readiness of the
    system to be used with Zoned Storage
    """
    # Get the OS General Information
    print("\nKernel and Distro General Information:")
    zbd_checker.utils.os_details.kernel_information()
    os_release = dict(zbd_checker.utils.os_details.check_distro())
    pretty_name = os_release.get('PRETTY_NAME')
    print(f'-- Distribution: {pretty_name} \n' )
    # Get the kernel configuration information
    print("Zone Block Support kernel config information: ")
    zbd_checker.utils.kernel_config_info.check_kernel_configs()
    # null_blk and scsi_debug modinfo check
    print(
    "\nCheck if null_blk and scsi_debug have Zoned Support in their loaded modules"
    )
    zbd_checker.utils.kernel_config_info.check_kernel_module()
    print(">>> To review these modules run these commands:")
    print ("-- sudo modinfo null_blk")
    print ("-- sudo modinfo scsi_debug")
    # Check to see what packages exists
    print("\nZone Block Package Status:")
    zbd_checker.utils.pkg_details.package_scan()
